@@ -18,7 +18,7 @@
 #
 
 from django.contrib import admin
-from models import *
+from .models import *
 
 admin.site.register(Profile)
 admin.site.register(Followed)
\ No newline at end of file
