@@ -20,8 +20,8 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-import logging, urlparse
-from django.shortcuts import render 
+import logging, urllib.parse
+from django.shortcuts import render
 from django.http import HttpResponse as response
 from django.conf import settings
 from django.template import Context,Template
@@ -29,18 +29,23 @@ from django import forms
 from django.http import Http404,HttpResponse
 from django.shortcuts import get_object_or_404, redirect
 from django.utils.translation import ugettext as _
-from models import Sellable,Basket,user
-from forms import BasketForm
-from feed import Mosaic
-from hooks import paypal_api
+from .models import Sellable,Basket,user
+from .forms import BasketForm
+from .feed import Mosaic
+from .hooks import paypal_api
 
 logger = logging.getLogger("feedly.views")
 
-from mezzanine.utils.views import render
-from mezzanine.conf import settings
-from cartridge.shop.models import Product, ProductVariation, Order, OrderItem
-from paypalrestsdk import Payment
-import paypalrestsdk
+# Optional dependencies
+
+try:
+    from mezzanine.utils.views import render
+    from mezzanine.conf import settings
+    from cartridge.shop.models import Product, ProductVariation, Order, OrderItem
+    from paypalrestsdk import Payment
+    import paypalrestsdk
+except ImportError as e:
+    logging.info("Extension modules deactivated: they could not be found.")
 
 class Baskets(Mosaic):
     def view_items(self,request):
@@ -60,14 +65,14 @@ class Baskets(Mosaic):
                 for i in range(int(request.REQUEST['qty'])-1):
                     s = Sellable(user=u,name=token,value=value,sellid=prodid,visual=visual); s.save()
         exists = Basket.objects.all().filter(user=u,product=prodid)
-        if not len(exists): 
+        if not len(exists):
             basket = Basket(user=u,product=prodid)
             basket.save()
         return self.view_items(request)
     def process_cart(self,request):
         u = self.current_user(request); cart = []
         basket = list(Basket.objects.filter(user=u))
-        for b in basket: 
+        for b in basket:
             sellables = Sellable.objects.filter(sellid=b.product)
             for s in sellables:
                 prod = {}
@@ -79,7 +84,7 @@ class Baskets(Mosaic):
     def clean_basket(self,request):
         u = self.current_user(request); cart = []
         basket = list(Basket.objects.filter(user=u))
-        for b in basket: 
+        for b in basket:
             Sellable.objects.filter(sellid=b.product).delete()
             b.delete()
         return response("Basket cleaned successfully")
@@ -88,7 +93,7 @@ class Baskets(Mosaic):
 
 class PagSeguro(Baskets):
     def process(self,request,cart=None):
-        for k,v in request.REQUEST.iteritems():
+        for k,v in request.REQUEST.items():
             if 'product' in k: product = v
             elif 'value' in k: value = float(v)
             elif 'qty' in k: qty = int(v)
@@ -108,7 +113,7 @@ class PagSeguro(Baskets):
 
 class PayPal(Baskets):
     def process(self,request,cart=None):
-        for k,v in request.REQUEST.iteritems():
+        for k,v in request.REQUEST.items():
             if 'product' in k: product = v
             elif 'value' in k: value = float(v)
             elif 'qty' in k: qty = int(v)
@@ -133,7 +138,7 @@ class PayPal(Baskets):
                 form_paypal.fields['amount_1'] = forms.IntegerField(widget=ValueHiddenInput(),initial=value)
                 form_paypal.fields['item_name_1'] = forms.CharField(widget=ValueHiddenInput(),initial=product)
                 form_paypal.fields['quantity_1'] = forms.CharField(widget=ValueHiddenInput(),initial=str(qty))
-            form_paypal.fields['cmd'] = forms.CharField(widget=ValueHiddenInput(),initial=option)        
+            form_paypal.fields['cmd'] = forms.CharField(widget=ValueHiddenInput(),initial=option)
             form_paypal.fields['upload'] = forms.CharField(widget=ValueHiddenInput(),initial='1')
         except (NameError,ImportError) as e:
             form_paypal = BasketForm(initial=paypal)
@@ -148,8 +153,8 @@ class Cartridge():
         for link in payment.links:
             if link.method == "REDIRECT":
                 redirect_url = link.href
-                url = urlparse.urlparse(link.href)
-                params = urlparse.parse_qs(url.query)
+                url = urllib.parse.urlparse(link.href)
+                params = urllib.parse.parse_qs(url.query)
                 redirect_token = params['token'][0]
                 order.paypal_redirect_token = redirect_token
                 order.save()
@@ -163,10 +168,10 @@ class Cartridge():
         elif not request.user.is_staff:
             lookup["user_id"] = request.user.id
         order = get_object_or_404(Order, **lookup)
-        is_pagseguro = order.pagseguro_redirect 
+        is_pagseguro = order.pagseguro_redirect
         if is_pagseguro is not None: return redirect(str(is_pagseguro))
         else: return self.paypal_redirect(request,order)
-    def payment_execute(self, request, template="shop/payment_confirmation.html"):    
+    def payment_execute(self, request, template="shop/payment_confirmation.html"):
         paypal_api()
         token = request.GET['token']
         payer_id = request.GET['PayerID']
